..  _testing:

Testing
=======
Stor provides a test case to use when testing against Swift storage. It also
provides a mixin class that can be used when creating other base test classes

.. automodule:: stor.test
.. autoclass:: stor.test.SwiftTestMixin
    :members:

.. autoclass:: stor.test.SwiftTestCase
    :members:
